@@ -1,4 +1,4 @@
-/* media.h -- This file is part of Archimedes release 0.1.0.
+/* media.h -- This file is part of Archimedes release 0.1.2.
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 Oct.2004, Siracusa, J.M.Sellier
-// Last modif. : 09 September 2007, Siracusa, J.M.Sellier
+// Last modif. : 12 September 2007, Siracusa, J.M.Sellier
 // ######################################################
 
 void media(void)
@@ -41,42 +41,45 @@ void media(void)
 
 // resetting of the electronic density
 // a simple way to avoid NaN propagation...
- for(i=1;i<=nx+1;i++)
-   for(j=1;j<=ny+1;j++){
+ for(i=0;i<=NXM;i++)
+   for(j=0;j<=NYM;j++){
      cont[i][j]=0;
      xvel[i][j]=0.;
      yvel[i][j]=0.;
      ener[i][j]=0.;
    }
  for(n=1;n<=INUM;n++){
+   int iaux;
    iv=(int)(P[n][0]);
-   x=P[n][5]/dx;
-   y=P[n][6]/dy;
-   i=(int)(x/dx)+1;
-   j=(int)(y/dy)+1;
+   x=P[n][5];
+   y=P[n][6];
+   i=(int)(x/dx+1.5);
+   j=(int)(y/dy+1.5);
    if(i<=1)  i=1;
    if(j<=1)  j=1;
-   if(i>=nx) i=nx;
-   if(j>=ny) j=ny;
+   if(i>=nx+1) i=nx+1;
+   if(j>=ny+1) j=ny+1;
+   if(NOVALLEY[i_dom[i][j]]==1) iaux=0;
+   if(NOVALLEY[i_dom[i][j]]==2) iaux=iv;
    ksquared=P[n][1]*P[n][1]+P[n][2]*P[n][2]+P[n][3]*P[n][3];
-   thesquareroot=sqrt(1.+4.*alphaK[i_dom[i][j]][1]*HHM[i_dom[i][j]][0]*ksquared);
-   superparticle_energy=(thesquareroot-1.)/(2.*alphaK[i_dom[i][j]][1]);
+   thesquareroot=sqrt(1.+4.*alphaK[i_dom[i][j]][iv]*HHM[i_dom[i][j]][iaux]*ksquared);
+   superparticle_energy=(thesquareroot-1.)/(2.*alphaK[i_dom[i][j]][iv]);
 // for the following two rows see
 // pag.10 formula (1.19) of Tomizawa,
 // "Numerical Simulation of Submicron Semiconductor
 //  Devices", 1993, ARTECH HOUSE
 // (this are due to the Kane non-parabolic energy band)
-   xvelocity=P[n][1]*HM[i_dom[i][j]][0]/thesquareroot;
-   yvelocity=P[n][2]*HM[i_dom[i][j]][0]/thesquareroot;
-   i=(int)(x+1.5);
-   j=(int)(y+1.5);
+   xvelocity=P[n][1]*HM[i_dom[i][j]][iaux]/thesquareroot;
+   yvelocity=P[n][2]*HM[i_dom[i][j]][iaux]/thesquareroot;
+   i=(int)(x/dx+1.5);
+   j=(int)(y/dy+1.5);
    if(i<1) i=1;
    if(j<1) j=1;
    if(i>=nx+1) i=nx+1;
    if(j>=ny+1) j=ny+1;
    cont[i][j]++;
    ener[i][j]+=superparticle_energy;
-   if(iv==2) ener[i][j] += EG[i_dom[i][j]];
+   ener[i][j]+=EMIN[i_dom[i][j]][iv];
    xvel[i][j]+=xvelocity;
    yvel[i][j]+=yvelocity;
  }
@@ -84,10 +87,10 @@ void media(void)
 // =======================================
   for(i=1;i<=nx+1;i++)
     for(j=1;j<=ny+1;j++){
-      if(cont[i][j]!=0.){
-          xvel[i][j]/=cont[i][j];
-          yvel[i][j]/=cont[i][j];
-          ener[i][j]/=cont[i][j];
+      if(cont[i][j]!=0){
+          xvel[i][j]/=(real)cont[i][j];
+          yvel[i][j]/=(real)cont[i][j];
+          ener[i][j]/=(real)cont[i][j];
       }
     }
 // =======================================
